@@ -1,14 +1,15 @@
 package Module::Install::Admin::Makefile;
 
-use Module::Install::Base;
-@ISA = qw(Module::Install::Base);
-
-$VERSION = '0.63';
-
 use strict 'vars';
-
+use Module::Install::Base;
 use ExtUtils::MakeMaker ();
 
+use vars qw{$VERSION @ISA};
+BEGIN {
+	$VERSION = '0.76';
+	@ISA     = qw{Module::Install::Base};
+}
+
 sub postamble {
     my ($self, $text) = @_;
     my $class       = ref($self);
@@ -21,7 +22,7 @@ sub postamble {
 realclean purge ::
 \t\$(RM_F) \$(DISTVNAME).tar\$(SUFFIX)
 \t\$(RM_RF) inc MANIFEST.bak _build
-\t\$(PERL) -I. -M$admin_class -e \"remove_meta()\"
+\t\$(PERL) -I. "-M$admin_class" -e "remove_meta()"
 
 reset :: purge
 
@@ -37,13 +38,15 @@ distsign ::
 END_MAKEFILE
 
     $self->{postamble} .= $text if defined $text;
-    $self->{postamble};
+    return $self->{postamble};
 }
 
 sub preop {
     my $self = shift;
+    my ($user_preop) = @_;
     my $admin_class = join('::', @{$self->_top}{qw(name dispatch)});
-    +{ PREOP => qq{\$(PERL) -I. -M$admin_class -e "dist_preop(q(\$(DISTVNAME)))"} }
+    $user_preop = qq{\$(PERL) -I. "-M$admin_class" -e "dist_preop(q(\$(DISTVNAME)))"} unless $user_preop;
+    return { PREOP => $user_preop };
 }
 
 1;
