@@ -1,7 +1,14 @@
 package Module::Install::AutoInstall;
 
+use strict;
 use Module::Install::Base;
-@ISA = qw{Module::Install::Base};
+
+use vars qw{$VERSION $ISCORE @ISA};
+BEGIN {
+	$VERSION = '0.76';
+	$ISCORE  = 1;
+	@ISA     = qw{Module::Install::Base};
+}
 
 sub AutoInstall { $_[0] }
 
