@@ -1,11 +1,14 @@
 package Module::Install::Inline;
 
-use Module::Install::Base;
-@ISA = qw(Module::Install::Base);
-
-$VERSION = '0.01';
-
 use strict;
+use Module::Install::Base;
+
+use vars qw{$VERSION $ISCORE @ISA};
+BEGIN {
+	$VERSION = '0.76';
+	$ISCORE  = 1;
+	@ISA     = qw{Module::Install::Base};
+}
 
 sub Inline { $_[0] }
 
@@ -18,10 +21,10 @@ sub write {
     my $version = $self->version
         or die "Please set version() or version_from() before calling &Inline->write\n";
 
-    $version =~ /^\d\.\d\d$/ or die << "END";
+    $version =~ /^\d\.\d\d$/ or die <<"END_MESSAGE";
 Invalid version '$version' for $name.
 Must be of the form '#.##'. (For instance '1.23')
-END
+END_MESSAGE
 
     $self->clean_files('_Inline', "$object.inl");
     $self->build_requires('Inline' => 0.44); # XXX: check for existing? yagni?
@@ -34,7 +37,7 @@ END
 .SUFFIXES: .pm .inl
 
 .pm.inl:
-\t\$(PERL) -I$prefix -Mblib -MInline=NOISY,_INSTALL_ -M$name -e1 $version \$(INST_ARCHLIB)
+\t\$(PERL) -I$prefix "-Mblib" "-MInline=NOISY,_INSTALL_" "-M$name" -e1 $version \$(INST_ARCHLIB)
 
 pure_all :: $object.inl
 
