@@ -1,25 +1,30 @@
 package Module::Install::MakeMaker;
 
+use strict;
 use Module::Install::Base;
-@ISA = qw(Module::Install::Base);
-
-$VERSION = '0.01';
-
 use ExtUtils::MakeMaker ();
 
+use vars qw{$VERSION $ISCORE @ISA};
+BEGIN {
+	$VERSION = '0.76';
+	$ISCORE  = 1;
+	@ISA     = qw{Module::Install::Base};
+}
+
 my $makefile;
+
 sub WriteMakefile {
     my ($self, %args) = @_;
     $makefile = $self->load('Makefile');
 
     # mapping between MakeMaker and META.yml keys
     $args{MODULE_NAME} = $args{NAME};
-    unless ($args{NAME} = $args{DISTNAME} or !$args{MODULE_NAME}) {
+    unless ( $args{NAME} = $args{DISTNAME} or ! $args{MODULE_NAME} ) {
         $args{NAME} = $args{MODULE_NAME};
         $args{NAME} =~ s/::/-/g;
     }
 
-    foreach my $key (qw(name module_name version version_from abstract author)) {
+    foreach my $key ( qw{name module_name version version_from abstract author installdirs} ) {
         my $value = delete($args{uc($key)}) or next;
         $self->$key($value);
     }
@@ -35,7 +40,7 @@ sub WriteMakefile {
 }
 
 END {
-    if ($makefile) {
+    if ( $makefile ) {
         $makefile->write;
         $makefile->Meta->write;
     }
